
#
# Internal schema definition of tables defined for a site.
#

#
# RepublishInfo Definition
#

CREATE TABLE RepublishInfo (
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00",
    VOList TEXT 
);

#
# SpecRecords Definition
#

CREATE TABLE SpecRecords (
    SpecID VARCHAR(255) NOT NULL,
    SiteName VARCHAR(50) NOT NULL,
    ClusterID VARCHAR(255) NOT NULL,
    SubClusterID VARCHAR(255) DEFAULT NULL,
    SpecInt2000 INT,
    SpecFloat2000 INT,
    EndDate DATE DEFAULT NULL,
    EndTime TIME DEFAULT NULL,
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00",
    PRIMARY KEY(SpecID, ClusterID, SpecInt2000),
    INDEX LcgJoin (SiteName)
);

#
# GkRecords Definition
#

CREATE TABLE GkRecords (
    GkID VARCHAR(255) PRIMARY KEY,
    GramScriptJobID VARCHAR(255) NOT NULL,
    LocalJobID VARCHAR(50),
    Processed INT,
    GlobalUserName VARCHAR(255),
    SiteName VARCHAR(50) NOT NULL,
    ValidFrom DATE DEFAULT NULL,
    ValidUntil DATE DEFAULT NULL,
    INDEX LcgJoin (GramScriptJobID)
);

#
# MessageRecords Definition
#

CREATE TABLE MessageRecords (
    MsgID VARCHAR(200) PRIMARY KEY,
    GramScriptJobID VARCHAR(255) NOT NULL,
    JobName VARCHAR(60) NOT NULL,
    Processed INT,
    SiteName VARCHAR(50) NOT NULL,
    ValidFrom DATE DEFAULT NULL,
    ValidUntil DATE DEFAULT NULL,
    INDEX LcgJoin (JobName)
);

#
# PbsRecord Definition
#

CREATE TABLE EventRecords (
    EventID VARCHAR(255) PRIMARY KEY,
    SiteName VARCHAR(50) NOT NULL,
    JobName VARCHAR(60) NOT NULL,
    LocalUserID VARCHAR(20),
    LocalUserGroup VARCHAR(20),
    WallDuration VARCHAR(30),
    CpuDuration VARCHAR(30),
    WallDurationSeconds INT,
    CpuDurationSeconds INT,
    StartTime VARCHAR(30),
    StopTime VARCHAR(30),
    StartTimeUTC VARCHAR(30),
    StopTimeUTC VARCHAR(30),
    StartTimeEpoch INT,
    StopTimeEpoch INT,
    SubmitHost VARCHAR(50) NOT NULL,
    MemoryReal INT,
    MemoryVirtual INT,
    Processed INT,
    EventDate DATE NOT NULL DEFAULT "000-00-00",
    EventTime TIME NOT NULL DEFAULT "00:00:00",
    INDEX LcgJoin_SiteName (SiteName),
    INDEX LcgJoin_JobName (JobName)
);

CREATE TABLE LcgRecords (
    RecordIdentity VARCHAR(255) PRIMARY KEY,
    ExecutingSite VARCHAR(50),
    LocalJobID VARCHAR(50),
    LCGJobID VARCHAR(255),
    LocalUserID VARCHAR(50),
    LCGUserID VARCHAR(255),
    LCGUserVO VARCHAR(255),
    ElapsedTime VARCHAR(30),
    BaseCpuTime VARCHAR(30),
    ElapsedTimeSeconds INT,
    BaseCpuTimeSeconds INT,
    StartTime VARCHAR(30),
    StopTime VARCHAR(30),
    StartTimeUTC VARCHAR(30),
    StopTimeUTC VARCHAR(30),
    StartTimeEpoch INT,
    StopTimeEpoch INT,
    ExecutingCE VARCHAR(255),
    MemoryReal INT,
    MemoryVirtual INT,
    SpecInt2000 INT,
    SpecFloat2000 INT,
    EventDate DATE NOT NULL DEFAULT "000-00-00",
    EventTime TIME NOT NULL DEFAULT "00:00:00",
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00"
);

#
# LcgProcessedFiles Definition
#

CREATE TABLE LcgProcessedFiles (
     FileName VARCHAR(100),
     FileType CHAR(1),
     SiteName VARCHAR(50),
     FilePath VARCHAR(200),
     HostName VARCHAR(100),
     PRIMARY KEY (FileName, FileType, SiteName, FilePath, HostName)
);

#
# BlahdRecords Definition
# 

CREATE TABLE BlahdRecords (
     BlahdID VARCHAR(255) PRIMARY KEY,
     TimeStamp DATETIME NOT NULL DEFAULT "0000-00-00 00:00:00",
     GlobalUserName VARCHAR(255) DEFAULT NULL,
     FullyQualifiedAttributeName VARCHAR(255) DEFAULT NULL,
     ResourceIdentity VARCHAR(255) DEFAULT NULL,
     GlobalJobId VARCHAR(255) DEFAULT NULL,
     LrmsId VARCHAR(255) DEFAULT NULL,
     JobName VARCHAR(255) DEFAULT NULL,
     SiteName VARCHAR(50) NOT NULL,
     ValidFrom DATE DEFAULT NULL,
     ValidUntil DATE DEFAULT NULL,
     Processed INT DEFAULT NULL
);
